@@ -49,7 +49,7 @@ class _Operator(object):
         self.items = items
 
     def __repr__(self):
-        return '(%s)' % (self.__class__.__name__, str(self))
+        return '(%s)' % (str(self))
 
     def __str__(self):
         return (' %s ' % self.sym).join(repr(i) for i in self.items)
@@ -151,7 +151,8 @@ class FormatTemplate(Field):
         if parent is None:
             return self
         
-        fields = {'meta': parent.meta}
+        fields = {'meta': parent.meta,
+                  'parent': parent}
         for name in parent.meta.fields:
             if getattr(parent.__class__, name) is not self:
                 fields[name] = getattr(parent, name)
@@ -186,7 +187,7 @@ class WithTags(Field):
         if self.not_tags:
             objects = objects.queryTagsDifference(*self.not_tags)
 
-        return list(objects)
+        return list(o for o in objects if not o.meta.abstract)
 
 
 def generator(func):
